@@ -23,7 +23,6 @@
 -- Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 ----------------------------------------------------------------------*/
 
-#include <assert.h>
 #include <stddef.h>
 #include "glpgel.h"
 #include "glpset.h"
@@ -312,7 +311,7 @@ loop: /* main loop starts here */
          t1 = t1new, t2 = t2new, k2--;
          goto loop;
       }
-      assert(tail == tail); /* relax compiler about never used */
+      insist(tail == tail); /* relax compiler about never used */
       /* igitur, the matrix U' has desired form, where the order of
          rows and columns of the original matrix U that form the matrix
          ing U' is determined by the linked list; it allows performing
