@@ -41,10 +41,9 @@
 -- passed to the build_lu routine. For more details see description of
 -- the build_lu routine. */
 
-#pragma argsused
-
 void monit_lu(LU *lu, int kase, int i, int k, double f)
 {     static clock_t t = 0;
+      insist(i == i && f == f);
       switch (kase)
       {  case 0:
             t = clock();
