@@ -276,21 +276,41 @@ int rsm1_driver(LP *_lp, LPSOL *_sol, struct rsm1_cp *_cp)
       rsm->tagn = ucalloc(1+n, sizeof(int));
       switch (cp->form)
       {  case 0:
-            /* use EFI */
-            rsm->efi = create_efi(m);
+            /* use PFI */
+            rsm->pfi = create_pfi(m);
             rsm->rfi = NULL;
+            rsm->afi = NULL;
+            rsm->ufi = NULL;
             break;
          case 1:
             /* use RFI + Bartels & Golub updating technique */
-            rsm->efi = NULL;
+            rsm->pfi = NULL;
             rsm->rfi = create_rfi(m);
             rsm->rfi->tech = RFI_BG;
+            rsm->afi = NULL;
+            rsm->ufi = NULL;
             break;
          case 2:
             /* use RFI + Forrest & Tomlin updating technique */
-            rsm->efi = NULL;
+            rsm->pfi = NULL;
             rsm->rfi = create_rfi(m);
             rsm->rfi->tech = RFI_FT;
+            rsm->afi = NULL;
+            rsm->ufi = NULL;
+            break;
+         case 3:
+            /* use AFI */
+            rsm->pfi = NULL;
+            rsm->rfi = NULL;
+            rsm->afi = create_afi(m);
+            rsm->ufi = NULL;
+            break;
+         case 4:
+            /* use UFI */
+            rsm->pfi = NULL;
+            rsm->rfi = NULL;
+            rsm->afi = NULL;
+            rsm->ufi = create_ufi(m);
             break;
          default:
             insist(cp->form != cp->form);
@@ -527,8 +547,10 @@ done: /* free working data structures */
       ufree(rsm->indb);
       ufree(rsm->indn);
       ufree(rsm->tagn);
-      if (rsm->efi != NULL) delete_efi(rsm->efi);
+      if (rsm->pfi != NULL) delete_pfi(rsm->pfi);
       if (rsm->rfi != NULL) delete_rfi(rsm->rfi);
+      if (rsm->afi != NULL) delete_afi(rsm->afi);
+      if (rsm->ufi != NULL) delete_ufi(rsm->ufi);
       ufree(rsm);
       ufree(R);
       ufree(S);
