@@ -37,8 +37,10 @@
 -- *Description*
 --
 -- The ucalloc routine allocates a memory block of (nmemb*size) bytes
--- long and clears the allocated block by binary zeros. If the operation
--- fails, abnormal program termination occurs.
+-- long.
+--
+-- Note that being allocated the memory block contains arbitrary data
+-- (not binary zeros).
 --
 -- *Returns*
 --
