@@ -200,7 +200,7 @@ struct bbm1_cp
       int form;
       /* this parameter specifies what form of the basis matrix should
          be used by the solver:
-         0 - EFI
+         0 - PFI
          1 - RFI + Bartels & Golub updating technique
          2 - RFI + Forrest & Tomlin updating technique */
       int steep;
