@@ -28,12 +28,12 @@
 
 #include "glpset.h"
 
-#define create_eta            glp_create_eta
-#define app_term              glp_app_term
-#define h_solve               glp_h_solve
-#define ht_solve              glp_ht_solve
-#define reset_eta             glp_reset_eta
-#define delete_eta            glp_delete_eta
+#define create_eta            _glp_create_eta
+#define app_term              _glp_app_term
+#define h_solve               _glp_h_solve
+#define ht_solve              _glp_ht_solve
+#define reset_eta             _glp_reset_eta
+#define delete_eta            _glp_delete_eta
 
 /* The structure HFILE defines so called eta-file which is a square
 -- matrix H represented in the following product form:
