@@ -29,15 +29,15 @@
 #include "glpduff.h"
 #include "glpmat.h"
 
-#define gel                   glp_gel
-#define gel_bg                glp_gel_bg
-#define gel_ft                glp_gel_ft
-#define min_bump              glp_min_bump
-#define create_lu             glp_create_lu
-#define build_lu              glp_build_lu
-#define monit_lu              glp_monit_lu
-#define solve_lu              glp_solve_lu
-#define delete_lu             glp_delete_lu
+#define gel                   _glp_gel
+#define gel_bg                _glp_gel_bg
+#define gel_ft                _glp_gel_ft
+#define min_bump              _glp_min_bump
+#define create_lu             _glp_create_lu
+#define build_lu              _glp_build_lu
+#define monit_lu              _glp_monit_lu
+#define solve_lu              _glp_solve_lu
+#define delete_lu             _glp_delete_lu
 
 extern int gel(MAT *V, PER *P, PER *Q,
       void (*func)(int i, int k, double f), double tol, double lim,
