@@ -26,14 +26,22 @@
 #ifndef _GLPIMG_H
 #define _GLPIMG_H
 
-#define create_img            glp_create_img
-#define reset_rgb             glp_reset_rgb
-#define get_imgval            glp_get_imgval
-#define set_imgval            glp_set_imgval
-#define delete_img            glp_delete_img
-#define save_as_bmp           glp_save_as_bmp
-#define save_as_tiff          glp_save_as_tiff
-#define save_img              glp_save_img
+#define create_img            _glp_create_img
+#define delete_img            _glp_delete_img
+#define get_imgval            _glp_get_imgval
+#define get_pixel             _glp_get_pixel
+#define line_to               _glp_line_to
+#define move_to               _glp_move_to
+#define reset_rgb             _glp_reset_rgb
+#define save_as_bmp           _glp_save_as_bmp
+#define save_as_tiff          _glp_save_as_tiff
+#define save_img              _glp_save_img
+#define set_clipreg           _glp_set_clipreg
+#define set_color             _glp_set_color
+#define set_imgval            _glp_set_imgval
+#define set_logorg            _glp_set_logorg
+#define set_pixel             _glp_set_pixel
+#define set_viewport          _glp_set_viewport
 
 typedef struct IMG IMG;
 typedef struct RGB RGB;
@@ -96,6 +104,8 @@ struct RGB
 #define IMG_YELLOW         0x0E
 #define IMG_WHITE          0x0F
 
+/*** base routines ***/
+
 extern IMG *create_img(int type, int xsize, int ysize);
 /* create raster image */
 
@@ -120,6 +130,32 @@ extern int save_as_tiff(IMG *img, char *fname);
 extern int (*save_img)(IMG *img, char *fname);
 /* write raster image using default format */
 
+/*** high-level routines ***/
+
+extern void set_color(IMG *img, int color);
+/* change current color index */
+
+extern void set_logorg(IMG *img, int x, int y);
+/* change base point */
+
+extern void set_clipreg(IMG *img, int x1, int y1, int x2, int y2);
+/* change clipping region */
+
+extern void set_viewport(IMG *img, int x1, int y1, int x2, int y2);
+/* change view port */
+
+extern int get_pixel(IMG *img, int x, int y);
+/* get color index of pixel */
+
+extern void set_pixel(IMG *img, int x, int y);
+/* set pixel to current color index */
+
+extern void move_to(IMG *img, int x, int y);
+/* change current point */
+
+extern void line_to(IMG *img, int x, int y);
+/* generate straightforward segment */
+
 #endif
 
 /* eof */
