@@ -28,8 +28,8 @@
 
 #include "glplp.h"
 
-#define ipm1                  glp_ipm1
-#define ipm1_driver           glp_ipm1_driver
+#define ipm1                  _glp_ipm1
+#define ipm1_driver           _glp_ipm1_driver
 
 extern int ipm1(MAT *A, double b[], double c[], double x[], double y[],
       double z[]);
