@@ -253,9 +253,11 @@ struct rsm1
       int form;
       /* this parameter specifies what form of the basis matrix should
          be used by the solver:
-         0 - EFI
+         0 - PFI
          1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique */
+         2 - RFI + Forrest & Tomlin updating technique
+         3 - AFI
+         4 - UFI */
       int scale;
       /* if this flag is set, the solver performs automatic scaling the
          problem; otherwise the scaling is not used */
@@ -328,9 +330,11 @@ struct bbm1
       int form;
       /* this parameter specifies what form of the basis matrix should
          be used by the solver:
-         0 - EFI
+         0 - PFI
          1 - RFI + Bartels & Golub updating technique
-         2 - RFI + Forrest & Tomlin updating technique */
+         2 - RFI + Forrest & Tomlin updating technique
+         3 - AFI
+         4 - UFI */
       int scale;
       /* if this flag is set, the solver performs automatic scaling the
          problem; otherwise the scaling is not used */
@@ -374,7 +378,7 @@ struct spx1
       int form;
       /* this parameter specifies what form of the basis matrix should
          be used by the solver:
-         0 - EFI
+         0 - PFI
          1 - RFI + Bartels & Golub updating technique
          2 - RFI + Forrest & Tomlin updating technique */
       int scale;
@@ -473,7 +477,7 @@ struct piv1
       int form;
       /* this parameter specifies what form of the basis matrix should
          be used by the routine:
-         0 - EFI
+         0 - PFI
          1 - RFI + Bartels & Golub updating technique
          2 - RFI + Forrest & Tomlin updating technique */
       int scale;
