@@ -82,9 +82,11 @@ static int scale = 1;
 static int form = 1;
 /* this parameter specifies what form of the basis matrix should be used
    by the solver:
-   0 - EFI
+   0 - PFI
    1 - RFI + Bartels & Golub updating technique
-   2 - RFI + Forrest & Tomlin updating technique */
+   2 - RFI + Forrest & Tomlin updating technique
+   3 - AFI
+   4 - UFI */
 
 static int use_dual = 0;
 /* if this flag is set, the solver uses the dual simplex method for
@@ -159,16 +161,17 @@ static void display_help(char *my_name)
       print("   -v, --version     display program version and exit");
       print("");
       print("Options specific to simplex method:");
-      print("   --textbook        use options --noscale, --efi, --prima"
+      print("   --textbook        use options --noscale, --pfi, --prima"
          "l, --nosteep,");
       print("                     --norelax, --first, and --lifo by def"
          "ault");
-      print("   --efi             use EFI");
+      print("   --pfi             use PFI");
       print("   --rfi-bg          use RFI + Bartels and Golub updating "
          "technique");
       print("                     (default)");
       print("   --rfi-ft          use RFI + Forrest and Tomlin updating"
          " technique");
+      print("   --afi             use AFI");
       print("   --primal          find feasible solution using primal s"
          "implex");
       print("                     (default)");
@@ -286,12 +289,16 @@ static void process_cmdline(int argc, char *argv[])
             branch = BB_FIRST;
             btrack = BB_LIFO;
          }
-         else if (p("--efi"))
+         else if (p("--pfi"))
             form = 0;
          else if (p("--rfi-bg"))
             form = 1;
          else if (p("--rfi-ft"))
             form = 2;
+         else if (p("--afi"))
+            form = 3;
+         else if (p("--ufi"))
+            form = 4;
          else if (p("--primal"))
             use_dual = 0;
          else if (p("--dual"))
